# Generated by Django 2.2.13 on 2020-08-22 16:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mpesa', '0004_auto_20200809_1604'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymenttransaction',
            name='order_id',
            field=models.CharField(max_length=200),
        ),
    ]
