# Generated by Django 2.2.5 on 2019-09-22 21:06

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='PaymentTransaction',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('phone_number', models.CharField(max_length=30)),
                ('amount', models.DecimalField(decimal_places=2, default=0, max_digits=6, verbose_name='amount')),
                ('isFinished', models.BooleanField(default=False)),
                ('isSuccessFull', models.BooleanField(default=False)),
                ('trans_id', models.CharField(max_length=30)),
                ('checkoutRequestID', models.CharField(max_length=100)),
                ('date_modified', models.DateTimeField(auto_now=True)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
