# Generated by Django 2.2.5 on 2020-08-08 13:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mpesa', '0002_wallet'),
    ]

    operations = [
        migrations.AddField(
            model_name='paymenttransaction',
            name='order_id',
            field=models.CharField(default=1, max_length=30),
            preserve_default=False,
        ),
    ]
